==> axiom-1.4.0-src.zip: axiom-1.4.0/testing/xml-testsuite/src/main/java/org/apache/axiom/ts/xml/MessageContent.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.axiom.ts.xml;

import java.io.InputStream;
import java.net.URL;

public abstract class MessageContent {
    public static MessageContent fromURL(URL url) {
        return new URLMessageContent(url);
    }
    
    public static MessageContent fromClasspath(Class<?> clazz, String relativeResourceName) {
        URL url = clazz.getResource(relativeResourceName);
        if (url == null) {
            throw new IllegalArgumentException(String.format(
                    "No such resource: %s (relative to %s)", relativeResourceName, clazz.getName()));
        }
        return fromURL(url);
    }
    
    public static MessageContent fromClasspath(ClassLoader classLoader, String resourceName) {
        URL url = classLoader.getResource(resourceName);
        if (url == null) {
            throw new IllegalArgumentException(String.format("No such resource: %s", resourceName));
        }
        return fromURL(url);
    }
    
    MessageContent() {}
    
    public abstract InputStream getInputStream();
    public abstract URL getURL();
}

==> axiom-2.0.0-src.zip: axiom-2.0.0/testing/xml-testsuite/src/main/java/org/apache/axiom/ts/xml/MessageContent.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.axiom.ts.xml;

import java.io.InputStream;
import java.net.URL;

public abstract class MessageContent {
    public static MessageContent fromURL(URL url) {
        return new URLMessageContent(url);
    }

    public static MessageContent fromClasspath(Class<?> clazz, String relativeResourceName) {
        URL url = clazz.getResource(relativeResourceName);
        if (url == null) {
            throw new IllegalArgumentException(
                    String.format(
                            "No such resource: %s (relative to %s)",
                            relativeResourceName, clazz.getName()));
        }
        return fromURL(url);
    }

    public static MessageContent fromClasspath(ClassLoader classLoader, String resourceName) {
        URL url = classLoader.getResource(resourceName);
        if (url == null) {
            throw new IllegalArgumentException(String.format("No such resource: %s", resourceName));
        }
        return fromURL(url);
    }

    MessageContent() {}

    public abstract InputStream getInputStream();

    public abstract URL getURL();
}
